---
title: <span class="badge object-type-enum"></span> HeatmapColorMode
---
# <span class="badge object-type-enum"></span> HeatmapColorMode

Controls the color mode of the heatmap

## Definition

```python
class HeatmapColorMode(enum.StrEnum):
    """
    Controls the color mode of the heatmap
    """

    OPACITY = "opacity"
    SCHEME = "scheme"
```
